@@ -1,6 +1,7 @@
 /*
     This file is part of HelpViewer (http://www.roard.com/helpviewer)
-    Copyright (C) 2003 Nicolas Roard (nicolas@roard.com)
+    Copyright (C) 2003 Nicolas Roard <nicolas@roard.com>
+                  2020 Riccardo Mottola <rm@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +14,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program; if not, write to the
+    Free Software Foundation, Inc.  
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
 #ifndef __LABEL_H__
@@ -32,10 +34,9 @@
     Part* part;
     NSString* _ID;
 }
-- (void) setBegin: (int) locationBegin;
-- (void) setEnd: (int) locationEnd;
 - (void) setPage: (Part*) part;
 - (void) setID: (NSString*) _ID;
+- (void) setRange: (NSRange)r;
 - (NSRange) range;
 - (Part*) page;
 - (NSString*) ID;
