@@ -1,6 +1,7 @@
 /*
     This file is part of HelpViewer (http://www.roard.com/helpviewer)
     Copyright (C) 2003 Nicolas Roard (nicolas@roard.com)
+                  2020 Riccardo Mottola <rm@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,35 +14,33 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program; if not, write to the
+    Free Software Foundation, Inc.  
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
 #include "Label.h"
 
 @implementation Label
 
-- (id) init {
-    self = [super init];
-
-    range.location = 0;
-    range.length = 0;
-    part = nil; 
-    _ID = nil;
-    return self;
+- (id) init
+{
+  if ((self = [super init]))
+    {
+      range.location = 0;
+      range.length = 0;
+      part = nil; 
+      _ID = nil;
+    }
+  return self;
 }
 
-- (void) dealloc {
-    RELEASE (_ID);
+- (void) dealloc
+{
+  RELEASE (_ID);
+  [super dealloc];
 }
 
-- (void) setBegin: (int) locationBegin {
-    range.location = locationBegin;
-}
-
-- (void) setEnd: (int) locationEnd {
-    range.length = locationEnd - range.location;
-}
 
 - (void) setPage: (Part*) _part {
     part = _part;
@@ -51,6 +50,11 @@
     ASSIGN (_ID, [__ID lowercaseString]);
 }
 
+- (void) setRange: (NSRange)r
+{
+  range = r;
+}
+
 - (NSRange) range {
     return range;
 }
