@@ -1,6 +1,7 @@
 /*
     This file is part of HelpViewer (http://www.roard.com/helpviewer)
-    Copyright (C) 2003 Nicolas Roard (nicolas@roard.com)
+    Copyright (C) 2003      Nicolas Roard (nicolas@roard.com)
+                  2020-2021 Riccardo Mottola <rm@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,33 +14,34 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program; if not, write to the
+    Free Software Foundation, Inc.  
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
 #ifndef __LEGEND_H__
 #define __LEGEND_H__
 
-#include <Foundation/Foundation.h>
-#include "GNUstep.h"
+#import <Foundation/Foundation.h>
+#import "GNUstep.h"
 
 @interface Legend : NSObject 
 {
     NSMutableAttributedString* legend;
     NSPoint point;
-    float height;
+    CGFloat height;
     BOOL rightPos;
 }
 + (id) legendWithString: (NSMutableAttributedString*) str andPoint: (NSPoint) p;
 - (id) initWithString: (NSMutableAttributedString*) str andPoint: (NSPoint) p;
 - (NSMutableAttributedString*) legend;
 - (NSPoint) point;
-- (float) height;
-- (void) setHeight: (float) h;
+- (CGFloat) height;
+- (void) setHeight: (CGFloat) h;
 - (void) setRightPos;
 - (void) setPoint: (NSPoint) p;
 - (BOOL) isRightPos;
-- (NSComparisonResult) compareLegends: (id) sender;
+- (NSComparisonResult) compareWith: (id)sender;
 @end
 
 #endif
