@@ -1,6 +1,7 @@
 /*
     This file is part of HelpViewer (http://www.roard.com/helpviewer)
-    Copyright (C) 2003 Nicolas Roard (nicolas@roard.com)
+    Copyright (C) 2003      Nicolas Roard (nicolas@roard.com)
+                  2020-2021 Riccardo Mottola <rm@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,8 +14,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    along with this program; if not, write to the
+    Free Software Foundation, Inc.  
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
 #include "TextFormatterXLP.h"
@@ -23,25 +25,22 @@
 
 @implementation TextFormatterXLP
 
-- (id) init {
-	self = [super init];
-	_firstSection = [[Section alloc] initWithHeader: @"document"];
-	_listCounter = [[NSMutableArray alloc] init];
-	legends = nil;
-	_currentSection = _firstSection;
-	_document = NO;
-	Bundle = nil;
-	content = nil;
-	return self;
+- (id) init
+{
+  if ((self = [super init]))
+    {
+      _firstSection = [[Section alloc] initWithHeader: @"document"];
+      _listCounter = [[NSMutableArray alloc] init];
+      legends = nil;
+      _currentSection = _firstSection;
+      _document = NO;
+      Bundle = nil;
+      content = nil;
+    }
+  return self;
 }
 
 - (void) startElement: (NSString*) elementName attributes: (NSMutableDictionary*) elementAttributes {
-    NSString* name = nil;
-    if ([elementAttributes objectForKey: @"name"] != nil)
-    {
-	name = [NSString stringWithString: [elementAttributes objectForKey: @"name"]];
-    }
-
     if (_pre)
     {
     	// verbatim mode
@@ -49,7 +48,6 @@
 	id str = [[NSMutableAttributedString alloc] initWithString: tag];
 
 	[tag release];
-	int i;
 	
 	NSEnumerator *enumerator = [elementAttributes keyEnumerator];
 	id key;
@@ -160,6 +158,7 @@
             [AS addAttribute: NSParagraphStyleAttributeName
                 value: paragraphStyle
                 range: NSMakeRange(0,[AS length])];
+	    [paragraphStyle release];
 	    [_currentContent appendAttributedString: AS];
             RELEASE (AS);
         }
@@ -321,7 +320,6 @@
 - (void) characters: (NSString*) name {
     NSMutableDictionary* attr = [NSMutableDictionary dictionaryWithCapacity: 2];
     NSFont* font = nil;
-    NSMutableString* value;
     NSFontTraitMask FontMask = 0;
     int FontSize = 12;
 
@@ -365,33 +363,33 @@
 
     [paragraphStyle setAlignment: NSLeftTextAlignment];
 
-    int FontSize = 12;
+    CGFloat fontSize = 12.0;
     int ruleHeight = 0;
 
     switch (level)
     {
 	case 0: 
-		FontSize = 24; 
+		fontSize = 24; 
 		FontMask = NSBoldFontMask | FontMask;
 		ruleHeight = 3;
 		break;
 	case 1: 
-		FontSize = 20; 
+		fontSize = 20; 
 		FontMask = NSBoldFontMask | FontMask;
 		ruleHeight = 1;
 		break;
 	case 2: 
-		FontSize = 16; 
+		fontSize = 16; 
 		FontMask = NSBoldFontMask | FontMask;
 		ruleHeight = 1;
 		break;
 	default:
-		FontSize = 12;
+		fontSize = 12;
 		FontMask = NSBoldFontMask | FontMask;
     }
 
     font = [[NSFontManager sharedFontManager]
-                convertFont: [NSFont userFontOfSize: FontSize]
+                convertFont: [NSFont userFontOfSize: fontSize]
                 toHaveTrait: FontMask];
 
     //[attr setObject: paragraphStyle forKey: NSParagraphStyleAttributeName];
@@ -407,6 +405,7 @@
     }
     NSMutableAttributedString* ahead = [[NSMutableAttributedString alloc] initWithString: header attributes: attr];
     [ret appendAttributedString: ahead];
+    [ahead release];
     if (ruleHeight) 
     {	
 	[self addRuleTo: ret withHeight: ruleHeight];
@@ -417,7 +416,7 @@
     return AUTORELEASE(ret);
 }
 
-- (void) addRuleTo: (NSMutableAttributedString*) string withHeight: (int) height {
+- (void) addRuleTo: (NSMutableAttributedString*) string withHeight: (CGFloat) height {
     if (height> 0)
     {
 	    NSTextAttachment* BR = [[NSTextAttachment alloc] init];
@@ -425,22 +424,26 @@
 
 	    BRCell* attachCell = [BRCell sharedBRCell];
 	    [BR setAttachmentCell: attachCell];
-	    NSMutableAttributedString* AS = [NSMutableAttributedString attributedStringWithAttachment: BR];
+
+	    NSMutableAttributedString* attStr = [[NSMutableAttributedString alloc] init];
+	    [attStr appendAttributedString: [NSAttributedString attributedStringWithAttachment: BR]];
     	    
 	    NSFont* font = [[NSFontManager sharedFontManager]
                 convertFont: [NSFont userFontOfSize: 1]
                 toHaveTrait: 0];
 
 	
-    	    //[AS addAttribute: NSFontAttributeName value: font range: NSMakeRange (0, [AS length])];
-	    [paragraphStyle setMaximumLineHeight: (float) height];
-    	    [AS addAttribute: NSParagraphStyleAttributeName value: paragraphStyle range: NSMakeRange (0, [AS length])];
-    	    //[AS addAttribute: NSBackgroundColorAttributeName value: [NSColor redColor] range: NSMakeRange (0, [AS length])];
-	    [AS addAttribute: @"BRCellHeight" value: [NSNumber numberWithInt: height] range: NSMakeRange (0,[AS length])];
+    	    //[attStr addAttribute: NSFontAttributeName value: font range: NSMakeRange (0, [attSStr length])];
+	    [paragraphStyle setMaximumLineHeight: (CGFloat) height];
+    	    [attStr addAttribute: NSParagraphStyleAttributeName value: paragraphStyle range: NSMakeRange (0, [attStr length])];
+	    [paragraphStyle release];
+    	    //[attStr addAttribute: NSBackgroundColorAttributeName value: [NSColor redColor] range: NSMakeRange (0, [attStr length])];
+	    [attStr addAttribute: @"BRCellHeight" value: [NSNumber numberWithInt: height] range: NSMakeRange (0,[attStr length])];
     	    NSMutableAttributedString* astring = [[NSMutableAttributedString alloc] initWithString: @"\n"];
 
 	    [string appendAttributedString: astring];
-	    [string appendAttributedString: AS];
+	    [string appendAttributedString: attStr];
+	    [attStr release];
 	    //[string appendAttributedString: astring];
     	    [astring release];
 	    RELEASE (BR);
@@ -466,23 +469,24 @@
 - (void) addImage: (NSImage*) img onString: (NSMutableAttributedString*) astring {
         NSTextAttachmentCell* attachCell = [[NSTextAttachmentCell alloc] initImageCell: img];
 
-        NSTextAttachment* Attachment = [[NSTextAttachment alloc] init];
-        [Attachment setAttachmentCell: attachCell];
+        NSTextAttachment* tAttachment = [[NSTextAttachment alloc] init];
+        [tAttachment setAttachmentCell: attachCell];
 
-        NSMutableAttributedString* t = [NSMutableAttributedString attributedStringWithAttachment: Attachment];
+        NSMutableAttributedString* t = [[NSMutableAttributedString alloc] init];
+	[t appendAttributedString: [NSMutableAttributedString attributedStringWithAttachment: tAttachment]];
         //[t setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [t length])];
 
     	[astring appendAttributedString: t];
-        RELEASE (img);
+	[t release];
         RELEASE (attachCell);
-        RELEASE (Attachment);
+        RELEASE (tAttachment);
 }
 
 
 - (void) addImage: (NSString*) pathname {
 
     NSString* file;
-    NSTextAttachment* Attachment;
+    NSTextAttachment* textAttachment;
 
     NSLog (@"addImage : %@", pathname);
 
@@ -501,17 +505,19 @@
 
         [wrapper setIcon: [NSImage imageNamed: @"Search.tiff"]];
 
-        Attachment = [[NSTextAttachment alloc] initWithFileWrapper: wrapper];
-        [Attachment setAttachmentCell: attachCell];
+        textAttachment = [[NSTextAttachment alloc] initWithFileWrapper: wrapper];
+        [textAttachment setAttachmentCell: attachCell];
 
-        NSMutableAttributedString* t = [NSMutableAttributedString attributedStringWithAttachment: Attachment];
+        NSMutableAttributedString* t = [[NSMutableAttributedString alloc] init];
+	[t appendAttributedString: [NSMutableAttributedString attributedStringWithAttachment: textAttachment]];
         //[t setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [t length])];
 
     	[_currentContent appendAttributedString: t];
+	[t release];
         RELEASE (img);
         RELEASE (wrapper);
         RELEASE (attachCell);
-        RELEASE (Attachment);
+        RELEASE (textAttachment);
     }
     else
     {
@@ -519,61 +525,45 @@
     }
 }
 
-- (void) addNote: (NSMutableAttributedString*) string withImage: (NSImage*) img withColor: (NSColor*) color {
-
-    //NSImage* img = [NSImage imageNamed: @"note.png"];
-
-    NSTextAttachment* BR = [[NSTextAttachment alloc] init];
+- (void) addNote: (NSMutableAttributedString*) string withImage: (NSImage*) img withColor: (NSColor*) color
+{
+    NSTextAttachment* textAttach = [[NSTextAttachment alloc] init];
     NoteCell* attachCell = [[NoteCell alloc] initWithTextView: textView];
-    
-    //    NSMakeSize ([textView bounds].size.width - 16, [img size].height)];
-        //NSMakeSize ([textView bounds].size.width, [img size].height)];
-
-    [[NSNotificationCenter defaultCenter] addObserver: attachCell
-        selector: @selector (resize:)
-        name: @"NSViewFrameDidChangeNotification"
-        object: textView];
 
     [attachCell setImage: img];
     [attachCell setColor: color];
     [attachCell setText: string];
     [attachCell resizeWithTextView: textView];
 
-    [BR setAttachmentCell: attachCell];
-    NSMutableAttributedString* AS = [NSMutableAttributedString attributedStringWithAttachment: BR];
-    //[AS setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [AS length])];
+    [[NSNotificationCenter defaultCenter] addObserver: attachCell
+					     selector: @selector (resize:)
+						 name: @"NSViewFrameDidChangeNotification"
+					       object: textView];
+
+    [textAttach setAttachmentCell: attachCell];
+    NSMutableAttributedString* attStr = [[NSMutableAttributedString alloc] init];
+    [attStr appendAttributedString: [NSMutableAttributedString attributedStringWithAttachment: textAttach]];
+    //[attStr setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [attStr length])];
     NSMutableAttributedString* astring = [[NSMutableAttributedString alloc] initWithString: @"\n"];
 
     [_currentContent appendAttributedString: astring];
+    [astring release];
 
-    [_currentContent appendAttributedString: AS];
-    RELEASE (BR);
+    [_currentContent appendAttributedString: attStr];
+    [attStr release];
+    RELEASE (textAttach);
     RELEASE (attachCell);
 }
 
-- (void) addLegendFig: (NSString*) imgpath withLegends: (NSArray*) plegends {
-
-    //NSImage* img = nil;
+- (void) addLegendFig: (NSString*) imgpath withLegends: (NSArray*) plegends
+{
     NSImage* img = [[NSImage alloc] initWithContentsOfFile: 
     	[Bundle pathForResource: [imgpath stringByDeletingPathExtension] 
 	ofType: [imgpath pathExtension]]];
 
     //NSLog (@"addLegendFig: %@ legends : %@", imgpath, plegends);
 
-/*
-    if ([[NSFileManager defaultManager] fileExistsAtPath: imgpath])
-    {
-        img = [[NSImage alloc] initWithContentsOfFile: imgpath];
-        //NSLog (@"addLegendFig (%@)", imgpath);
-    }
-    else
-    {
-        NSString* mpath = [NSString stringWithFormat: @"%@/%@", path, imgpath];
-        img = [[NSImage alloc] initWithContentsOfFile: mpath];
-        //NSLog (@"addLegendFig (%@)", mpath);
-    }
-*/
-    NSTextAttachment* BR = [[NSTextAttachment alloc] init];
+    NSTextAttachment* textAttach = [[NSTextAttachment alloc] init];
     FigureCell* attachCell = [[FigureCell alloc] initWithSize:
         NSMakeSize ([textView bounds].size.width, [img size].height)];
 
@@ -585,12 +575,15 @@
     [attachCell setImage: img];
     [attachCell setLegends: plegends];
     [attachCell resizeWithTextView: textView];
-    [BR setAttachmentCell: attachCell];
-    NSMutableAttributedString* AS = [NSMutableAttributedString attributedStringWithAttachment: BR];
-    [AS setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [AS length])];
+    [textAttach setAttachmentCell: attachCell];
 
-    [_currentContent appendAttributedString: AS];
-    RELEASE (BR);
+    NSMutableAttributedString* attStr = [[NSMutableAttributedString alloc] init];
+    [attStr appendAttributedString: [NSMutableAttributedString attributedStringWithAttachment: textAttach]];
+    [attStr setAlignment: NSCenterTextAlignment range: NSMakeRange (0, [attStr length])];
+
+    [_currentContent appendAttributedString: attStr];
+    [attStr release];
+    RELEASE (textAttach);
     RELEASE (attachCell);
     RELEASE (img);
 }
